@@ -5,12 +5,12 @@ import logging
 import math
 from typing import Any, Dict, Optional, Tuple
 
-import numpy as np  # type: ignore
+import numpy as np
 import pyrr
 
-from payton.math.vector import Vector3D
-from payton.math.geometry import raycast_plane_intersect
 from payton.math.functions import sub_vector
+from payton.math.geometry import raycast_plane_intersect
+from payton.math.vector import Vector3D
 from payton.scene.geometry.base import Object
 
 BUTTON_LEFT = 1
@@ -173,10 +173,8 @@ class Camera:
 
         _ct = _theta + math.radians(theta)
         _cp = _phi + math.radians(phi)
-        if _ct < 0.001:
-            _ct = 0.001
-        if _ct > 3.13:
-            _ct = 3.13
+        _ct = max(_ct, 0.001)
+        _ct = min(_ct, 3.13)
 
         x = r * math.sin(_ct) * math.cos(_cp)
         y = r * math.sin(_ct) * math.sin(_cp)
@@ -256,7 +254,7 @@ class Camera:
         if button == BUTTON_MIDDLE:
             self.pan(x, y, w, h)
 
-    def mouse_wheel(self, yrel: int):
+    def mouse_wheel(self, yrel: int) -> None:
         """Mouse wheel event handler for zoom
 
         Keyword arguments:
@@ -291,7 +289,7 @@ class Camera:
 
     def render(self) -> Tuple[np.ndarray, np.ndarray]:
         """Render the camera"""
-        if self._use_cache and self.target_object is None:
+        if self._use_cache and self.target_object is None and self._projection is not None and self._view is not None:
             return self._projection, self._view
 
         if self.perspective:
@@ -307,8 +305,7 @@ class Camera:
             y = 70
             if self.zoom == 0:
                 self.zoom = 0.01
-            if self.near < 1:
-                self.near = 1
+            self.near = max(self.near, 1)
             proj_matrix = pyrr.matrix44.create_orthogonal_projection_matrix(
                 left=(-x / self.zoom),
                 right=(x / self.zoom),
@@ -324,7 +321,7 @@ class Camera:
 
         if self.target_object:
             # I believe there is a bug at mypy about @property methods
-            self.target = self.target_object.position  # type: ignore
+            self.target = self.target_object.position
 
         target = np.array(list(self.target), dtype=np.float32)
         up = np.array(list(self.up), dtype=np.float32)
