@@ -1,10 +1,11 @@
+"""Export Import all to JSON."""
 from typing import Any
 
 from payton.scene.geometry.mesh import Mesh
 
 
 def export_json(mesh: Mesh, filename: str, **kwargs: Any) -> None:
-    """Export the given mesh as JSON
+    """Export the given mesh as JSON.
 
     Keyword arguments:
     mesh -- Mesh to export
@@ -15,9 +16,10 @@ def export_json(mesh: Mesh, filename: str, **kwargs: Any) -> None:
 
 
 def import_json(filename: str) -> Mesh:
-    """Import the given file as a Mesh
+    """Import the given file as a Mesh.
 
     Keyword arguments:
-    filename -- Filename to import"""
+    filename -- Filename to import
+    """
     data = open(filename, "r").read()
     return Mesh.from_json(data)
