@@ -1,7 +1,7 @@
 import ctypes
 from typing import Any, List, Optional
 
-import numpy as np  # type: ignore
+import numpy as np
 from OpenGL.GL import (
     GL_ARRAY_BUFFER,
     GL_ELEMENT_ARRAY_BUFFER,
@@ -52,11 +52,7 @@ class Grid:
         yres -- Number of steps in Y direction
         color -- Color of the grid.
         """
-        if color is None:
-            self._color = [0.4, 0.4, 0.4, 1.0]
-        else:
-            self._color = color
-
+        self._color = [0.4, 0.4, 0.4, 1.0] if color is None else color
         self.static: bool = True
         self.matrix: List[float] = [
             1.0,
@@ -134,6 +130,9 @@ class Grid:
         if self._vao == -1:
             self.build()
 
+        if self._model_matrix is None:
+            return True
+
         shader.set_matrix4x4_np("model", self._model_matrix)
         self._material.render(False, shader)
 
@@ -167,15 +166,15 @@ class Grid:
         ystart = -(yres * spacing / 2.0)
         xstart = -(xres * spacing / 2.0)
         self._model_matrix = np.asfortranarray(np.array(self.matrix, dtype=np.float32), dtype=np.float32)
-        for j in range(0, yres):
+        for j in range(yres):
             y = ystart + (j * spacing)
-            for i in range(0, xres):
+            for i in range(xres):
                 x = xstart + (i * spacing)
                 self._vertices += [x, y, 0.0]
 
-        for j in range(0, yres - 1):
+        for j in range(yres - 1):
             offset = j * xres
-            for i in range(0, xres - 1):
+            for i in range(xres - 1):
                 k = offset + i
                 self._indices += [
                     k,
